package de.intevation.flys.client.shared.model;

import java.util.List;

/**
 * @author <a href="mailto:bjoern.ricks@intevation.de">Björn Ricks</a>
 */

public class DefaultRiverInfo implements RiverInfo {

    private String name;
    private boolean kmup;
    private Double start;
    private Double end;
    private String wstunit;
    private Double minq;
    private Double maxq;
    private String infourl;

    private List<GaugeInfo> gaugeinfo;

    public DefaultRiverInfo() {
    }

    public DefaultRiverInfo(
            String name,
            boolean kmup,
            Double start,
            Double end,
            String wstunit,
            Double minq,
            Double maxq,
            String infourl,
            List<GaugeInfo> gaugeinfo)
    {
        this.name = name;
        this.kmup = kmup;
        this.start = start;
        this.end = end;
        this.wstunit = wstunit;
        this.minq = minq;
        this.maxq = maxq;
        this.infourl = infourl;
        this.gaugeinfo = gaugeinfo;
    }


    public boolean isKmUp() {
        return this.kmup;
    }

    /**
     * Start KM of the river
     */
    public Double getKmStart() {
        return this.start;
    }

    /**
     * End KM of the river
     */
    public Double getKmEnd() {
        return this.end;
    }

    /**
     * Returns the name of the river
     */
    public String getName() {
        return this.name;
    }

    /**
     * Returns the name of the WST unit
     */
    public String getWstUnit() {
        return this.wstunit;
    }

    /**
     * Return all gauge info of the river
     */
    public List<GaugeInfo> getGauges() {
        return this.gaugeinfo;
    }

    /**
     * Returns the min q value of the river
     */
    public Double getMinQ() {
        return this.minq;
    }

    /**
     * Returns the max q value of the river
     */
    public Double getMaxQ() {
        return maxq;
    }

    /**
     * Returns the URL where to find additional information about this river
     */
    public String getInfoURL() {
        return this.infourl;
    }
}
